@@ -182,18 +182,19 @@ func (c *Config) runAddCmd(cmd *cobra.Command, args []string, sourceState *chezm
 		c.destSystem,
 		destAbsPathInfos,
 		&chezmoi.AddOptions{
-			AutoTemplate:    c.Add.autoTemplate,
-			Create:          c.Add.create,
-			Encrypt:         c.Add.Encrypt,
-			EncryptedSuffix: c.encryption.EncryptedSuffix(),
-			Exact:           c.Add.exact,
-			Filter:          c.Add.filter,
-			OnIgnoreFunc:    c.defaultOnIgnoreFunc,
-			PreAddFunc:      c.defaultPreAddFunc,
+			AutoTemplate:      c.Add.autoTemplate,
+			Create:            c.Add.create,
+			Encrypt:           c.Add.Encrypt,
+			EncryptedSuffix:   c.encryption.EncryptedSuffix(),
+			Exact:             c.Add.exact,
+			Filter:            c.Add.filter,
+			OnIgnoreFunc:      c.defaultOnIgnoreFunc,
+			PreAddFunc:        c.defaultPreAddFunc,
+			ConfigFileAbsPath: c.getConfigFileAbsPath(),
 			ProtectedAbsPaths: []chezmoi.AbsPath{
 				c.CacheDirAbsPath,
 				c.WorkingTreeAbsPath,
-				c.getConfigFileAbsPath(),
+				c.getConfigFileAbsPath().Dir(),
 				persistentStateFileAbsPath,
 				c.sourceDirAbsPath,
 			},
