@@ -41,7 +41,6 @@ import (
 	"github.com/twpayne/go-shell"
 	"github.com/twpayne/go-vfs/v5"
 	"github.com/twpayne/go-xdg/v6"
-	cobracompletefig "github.com/withfig/autocomplete-tools/integrations/cobra"
 	"github.com/zricethezav/gitleaks/v8/detect"
 	"golang.org/x/term"
 	"mvdan.cc/sh/v3/expand"
@@ -1651,7 +1650,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newUpdateCmd(),
 		c.newUpgradeCmd(),
 		c.newVerifyCmd(),
-		cobracompletefig.CreateCompletionSpecCommand(),
 	} {
 		if cmd != nil {
 			registerCommonFlagCompletionFuncs(cmd)
@@ -2599,7 +2597,7 @@ func (c *Config) tempDir(key string) (chezmoi.AbsPath, error) {
 		return tempDirAbsPath, nil
 	}
 	tempDir, err := os.MkdirTemp("", key)
-	chezmoilog.InfoOrError(c.logger, "MkirTemp", err, slog.String("tempDir", tempDir))
+	chezmoilog.InfoOrError(c.logger, "MkdirTemp", err, slog.String("tempDir", tempDir))
 	if err != nil {
 		return chezmoi.EmptyAbsPath, err
 	}
