@@ -52,11 +52,7 @@ func (c *Config) newMackupCmd() *cobra.Command {
 			requiresSourceDirectory,
 		),
 	}
-	mackupAddCmdPersistentFlags := mackupAddCmd.PersistentFlags()
-	mackupAddCmdPersistentFlags.Var(&c.Add.Secrets, "secrets", "Scan for secrets when adding unencrypted files")
-	if err := mackupAddCmd.RegisterFlagCompletionFunc("secrets", severityFlagCompletionFunc); err != nil {
-		panic(err)
-	}
+	mackupAddCmd.Flags().Var(&c.Add.Secrets, "secrets", "Scan for secrets when adding unencrypted files")
 	mackupCmd.AddCommand(mackupAddCmd)
 
 	// FIXME add other subcommands like
